==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterRelocateStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterRelocateStatusBuilder extends ClusterRelocateStatusFluentImpl<ClusterRelocateStatusBuilder> implements VisitableBuilder<ClusterRelocateStatus,ClusterRelocateStatusBuilder>{
  public ClusterRelocateStatusBuilder() {
    this(false);
  }
  public ClusterRelocateStatusBuilder(Boolean validationEnabled) {
    this(new ClusterRelocateStatus(), validationEnabled);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterRelocateStatus(), validationEnabled);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatusFluent<?> fluent,ClusterRelocateStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatusFluent<?> fluent,ClusterRelocateStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatus instance) {
    this(instance,false);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterRelocateStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterRelocateStatus build() {
    ClusterRelocateStatus buildable = new ClusterRelocateStatus();
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterRelocateStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterRelocateStatusBuilder extends ClusterRelocateStatusFluent<ClusterRelocateStatusBuilder> implements VisitableBuilder<ClusterRelocateStatus,ClusterRelocateStatusBuilder>{
  public ClusterRelocateStatusBuilder() {
    this(false);
  }
  public ClusterRelocateStatusBuilder(Boolean validationEnabled) {
    this(new ClusterRelocateStatus(), validationEnabled);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterRelocateStatus(), validationEnabled);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatusFluent<?> fluent,ClusterRelocateStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatusFluent<?> fluent,ClusterRelocateStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterRelocateStatus());

    if (instance != null) {
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatus instance) {
    this(instance,false);
  }
  public ClusterRelocateStatusBuilder(ClusterRelocateStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterRelocateStatus());

    if (instance != null) {
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterRelocateStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterRelocateStatus build() {
    ClusterRelocateStatus buildable = new ClusterRelocateStatus();
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
